Index: trunk/ippScripts/scripts/receive_file.pl
===================================================================
--- trunk/ippScripts/scripts/receive_file.pl	(revision 31567)
+++ trunk/ippScripts/scripts/receive_file.pl	(revision 35976)
@@ -223,7 +223,8 @@
     } elsif ($runType eq 'staticskyRun') {
         $stage = 'sky';
-        # XXX: This should be skycell, but the distribution code uses exposure
         $comp_name = 'skycell_id';
-#        $current_component = $comp_name;
+    } elsif ($runType eq 'skycalRun') {
+        $stage = 'skycal';
+        $comp_name = 'skycell_id';
     } else {
         &my_die( "unexpected run type line found in $filename: $runType\n", $file_id, $PS_EXIT_UNKNOWN_ERROR);
@@ -238,6 +239,6 @@
     }
 
-    if ($stage eq 'sky') {
-        # the dbinfo file for a skyRun only has one component and it doesn't contain
+    if ($stage eq 'sky' or $stage = 'skycal') {
+        # the dbinfo file for staticskyRun and skycalRun only have one component and they don't contain
         # skycell_id which is the way components are listed in the dirinfo file.
         my @ids = keys %$components;
